function uisplitting(hObject,handles)

% menu for splitting analysis

% Copyright 2016 M.Reiss and G.Rümpker, altered May 2019

global sel_data e1 e2 e4 e5 pd1 pb1

% main panel
hsp_prep = uipanel('units','normalized','position',[.2 .0 .8 1]);

% main button group
split_bg = uibuttongroup('Parent',hsp_prep,'Visible', 'on','Position', ...
    [.0 .0 1 1]);

%title string
title_str = uicontrol(split_bg,'Style','text','Visible','on','Units',...
    'normalized','position',[0.1,0.92,0.8,0.05],'String',...
    'Select splitting analysis parameters',...
    'fontunits','normalized','fontsize',0.8);

%% button group for setting analysis parameters

split_bg1 = uibuttongroup('Parent',hsp_prep,'Title',...
    'Set analysis parameters','Visible', 'on','Position', ...
    [.0 .0 .5 .85],'fontunits','normalized','fontsize',0.05);

txt = uicontrol(split_bg1,'Style','text','Visible','on','Units',...
    'normalized','position',[0.1,0.8,0.8,0.1],'String',...
    'Load settings from ...', 'fontunits','normalized','fontsize',0.33);

% all buttons are set to disable until previous settings are loaded

[disp_stations] = disp_st_lst;

txt1 = uicontrol(split_bg1,'Style','text','Visible','on','Units',...
    'normalized','position',[0.05,0.56,0.4,0.1],'String',...
    'Choose station', 'fontunits','normalized','fontsize',0.33);

pd1 = uicontrol(split_bg1,'Style','popupmenu', 'String',disp_stations,...
    'Units', 'normalized','position',[0.5,0.56,0.4,0.1],...
    'enable', 'off','fontunits','normalized',...
    'fontsize', 0.33,'Callback',@uiget_st);

txt2 = uicontrol(split_bg1,'Style','text','Visible','on','Units', ...
    'normalized','position',[0.05,0.45,0.4,0.1],'String','Filter [s]',...
    'fontunits','normalized','fontsize',0.33);

txt3 = uicontrol(split_bg1,'Style','text','Units', 'normalized',...
    'position',[0.5,0.45,0.4,0.1],'String','-','fontunits',...
    'normalized','fontsize',0.33);

e1 = uicontrol(split_bg1, 'Style', 'edit','String','','enable', 'off',...
    'Units', 'normalized', 'position',[0.5,0.5,0.15,0.05],...
    'Callback',@uiget_p1);

e2 = uicontrol(split_bg1, 'Style', 'edit','String','','enable', 'off',...
    'Units', 'normalized', 'position',[0.75,0.5,0.15,0.05],...
    'Callback',@uiget_p2);

txt5 = uicontrol(split_bg1,'Style','text','Units', 'normalized',...
    'position',[0.05,0.365,0.4,0.1],'String',...
    'Choose no. of time windows','fontunits','normalized','fontsize',0.33);

e4 = uicontrol(split_bg1, 'Style', 'edit','String','50','enable', 'off',...
    'Units', 'normalized', 'position',[0.5,0.4,0.15,0.05],...
    'Callback',@uiget_ntw);

txt6 = uicontrol(split_bg1,'Style','text','Units', 'normalized',...
    'position',[0.05,0.24,0.4,0.1],'String','Choose phi range',...
    'fontunits','normalized','fontsize',0.33);

r1 = uicontrol(split_bg1,'Style','radiobutton', 'String',...
    '(-90)° - 90°', 'units','normalized', 'Position',[0.5 .28 .25 .09],...
    'HandleVisibility','on','Tag','Button1','enable', 'off');
r2 = uicontrol(split_bg1,'Style','radiobutton','String','0° - 180°',...
    'units','normalized','Position',[0.75 .28 .25 .09],...
    'HandleVisibility','on','Tag','Button2','enable', 'off');

set(split_bg1,'SelectionChangeFcn', {@uiget_fa_area,split_bg1});
set(split_bg1,'SelectedObject',r1)

txt7 = uicontrol(split_bg1,'Style','text','Units', 'normalized',...
    'position',[0.05,0.18,0.95,0.1],'String','misalignment correction',...
    'fontunits','normalized','fontsize',0.33);

cb1 = uicontrol(split_bg1,'Style','checkbox','units','normalized', ...
    'Position',[0.05 .16 .07 .07],...
    'HandleVisibility','on','value',1,'Tag','cb1','enable', 'off');

txt77 = uicontrol(split_bg1,'Style','text','Units','normalized',...
    'position', [0.1,0.12,0.2,0.1],'String','mean val.',...
    'fontunits','normalized','fontsize',0.33);

cb2 = uicontrol(split_bg1,'Style','checkbox','units','normalized', ...
    'Position',[0.35 .16 .07 .07],...
    'HandleVisibility','on','value',0,'Tag','cb2','enable', 'off');

txt777 = uicontrol(split_bg1,'Style','text','Units','normalized',...
    'position', [0.4,0.12,0.2,0.1],'String','per event',...
    'fontunits','normalized','fontsize',0.33);

cb3 = uicontrol(split_bg1,'Style','checkbox','units','normalized', ...
    'Position',[0.62 .16 .07 .07],...
    'HandleVisibility','on','value',0,'Tag','cb3','enable', 'off');

txt7777 = uicontrol(split_bg1,'Style','text','Units','normalized',...
    'position', [0.66,0.12,0.16,0.1],'String','value:',...
    'fontunits','normalized','fontsize',0.33);

e5 = uicontrol(split_bg1, 'Style','edit','String','0','enable','off',...
    'Units','normalized','position',[0.8,0.17,0.15,0.05]);

%% Splitting Analysis Button Group

split_bg2 = uibuttongroup('Parent',hsp_prep,'Visible', 'on','Position', ...
    [.5 .0 .5 .85],'Title','Splitting Analysis', 'fontunits',...
    'normalized','fontsize',0.05);

txt0 = uicontrol(split_bg2,'Style','text','Visible','on','Units',...
    'normalized','position',[0.1,0.8,0.8,0.1],'String',...
    'Single Splitting Analysis','fontunits','normalized',...
    'fontsize',0.33,'FontWeight','bold');

pb11 = uicontrol(split_bg2,'Style','pushbutton','Units', 'normalized',...
    'position',[0.05,0.73,0.4,0.1],'String',...
    'do analysis','enable', 'off','fontunits',...
    'normalized','fontsize',0.33,'Callback',...
    {@uigetinput,4});

pb22 = uicontrol(split_bg2,'Style','pushbutton','Units', 'normalized',...
    'position',[0.55,0.73,0.4,0.1],'String',...
    '<html>show & cate-<br>gorize results','enable', 'off','fontunits',...
    'normalized','fontsize',0.33,'Callback',...
    {@uigetinput,5});

pb33 = uicontrol(split_bg2,'Style','pushbutton','Units', 'normalized',...
    'position',[0.05,0.57,0.4,0.1],'String',...
    'overview','enable', 'off','fontunits',...
    'normalized','fontsize',0.33,'Callback',...
    {@uigetinput,6});

pb44 = uicontrol(split_bg2,'Style','pushbutton','Units', 'normalized',...
    'position',[0.55,0.57,0.4,0.1],'String',...
    '<html>export results<br>and waveforms','enable', 'off','fontunits',...
    'normalized','fontsize',0.33,'Callback',...
    {@ui_export_si_sp});

txt00 = uicontrol(split_bg2,'Style','text','Visible','on','Units',...
    'normalized','position',[0.1,0.43,0.8,0.1],'String',...
    'Joint Splitting Analysis','fontunits','normalized',...
    'fontsize',0.33,'FontWeight','bold');

pb111 = uicontrol(split_bg2,'Style','pushbutton','Units', 'normalized',...
    'position',[0.05,0.36,0.4,0.1],'String',...
    'single layer','enable', 'off','fontunits',...
    'normalized','fontsize',0.33,'Callback',...
    {@uigetinput,7});

pb222 = uicontrol(split_bg2,'Style','pushbutton','Units', 'normalized',...
    'position',[0.55,0.36,0.4,0.1],'String',...
    'two layers','enable', 'off','fontunits',...
    'normalized','fontsize',0.33,'Callback',...
    {@uigetinput,8});

pb333 = uicontrol(split_bg2,'Style','pushbutton','Units', 'normalized',...
    'position',[0.05,0.21,0.4,0.1],'String',...
    'show results','enable', 'off','fontunits',...
    'normalized','fontsize',0.33,'Callback',...
    {@uigetinput,9});

pb444 = uicontrol(split_bg2,'Style','pushbutton','Units', 'normalized',...
    'position',[0.55,0.21,0.4,0.1],'String',...
    'show results','enable', 'off','fontunits',...
    'normalized','fontsize',0.33,'Callback',...
    {@uigetinput,10});

pb555 = uicontrol(split_bg2,'Style','pushbutton','Units', 'normalized',...
    'position',[0.05,0.06,0.4,0.1],'String',...
    '<html>export results<br>and waveforms','enable', 'off','fontunits',...
    'normalized','fontsize',0.33,'Callback',...
    {@ui_export_js,1});

pb666 = uicontrol(split_bg2,'Style','pushbutton','Units', 'normalized',...
    'position',[0.55,0.06,0.4,0.1],'String',...
    '<html>export results<br>and waveforms','enable', 'off','fontunits',...
    'normalized','fontsize',0.33,'Callback',...
    {@ui_export_js,2});

%% ok button to enable Splitting Button group

pb0 = uicontrol(split_bg1,'Style','pushbutton','Units', 'normalized',...
    'position',[0.05,0.03,0.4,0.1],'String', 'OK','fontunits',...
    'normalized','fontsize',0.33,'enable','off','Callback',...
    {@ui_ok,split_bg1,r1,r2,pb11,pb22,pb33,pb44,pb111,pb222,pb333,pb444,...
    pb555,pb666, cb1,cb2,cb3});

%% load settings button to enable setting group

pb1 = uicontrol(split_bg1,'Style','pushbutton', 'String',...
    'pre-processing','units','normalized', ...
    'Position',[0.05,0.73,0.4,0.1],...
    'fontunits','normalized','fontsize',0.33,...
    'HandleVisibility','on','Callback',...
    {@uiset_set,split_bg1,pd1,r1,r2,cb1,cb2,cb3,pb0,1});

pb2 = uicontrol(split_bg1,'Style','pushbutton', 'String',...
    '<html>previous<br>splitting analysis','units','normalized', ...
    'Position',[0.5 .73 .4 .1],'fontunits', 'normalized',...
    'fontsize',0.333, 'HandleVisibility','on','Callback',...
    {@uiset_set,split_bg1,pd1,r1,r2,cb1,cb2,cb3,pb0,2});


end


function uiset_set(hObject,handles,split_bg1,pd1,r1,r2,cb1,cb2,cb3,pb0,flag)

% get settings for splitting analysis from previously save files

global sel_data e1 e2 e4 C

if flag == 1 % from pre-processing
    
    % read file
    [sel_data.set_file, sel_data.set_folder] = ...
        uigetfile('*.txt','please select file with saved settings',...
        [sel_data.work_dir,'/processed_data/']);
    
    fileID = fopen([sel_data.set_folder,sel_data.set_file]);
    C = textscan(fileID,'%f %f %3.1f');
    fclose(fileID);
    
    % write in editable fields
    
    e1 = uicontrol(split_bg1, 'Style', 'edit','String',C{1},'enable', ...
        'on', 'Units', 'normalized', 'position',[0.5,0.5,0.15,0.05],...
        'Callback',@uiget_p1);
    
    e2 = uicontrol(split_bg1, 'Style', 'edit','String',C{2},'enable',...
        'on','Units', 'normalized', 'position',[0.75,0.5,0.15,0.05],...
        'Callback',@uiget_p2);
    
    % get SNR
    sel_data.snr = C{3};
    
    %enable unset buttons
    set(e4,'enable','on')
    set(r1,'enable','on')
    set(r2,'enable','on')
    set(cb1,'enable','on', 'Callback',{@uiget_cordeg,cb1,cb2,cb3})
    set(cb2,'enable','on', 'Callback',{@uiget_cordeg,cb2,cb3,cb1})
    set(cb3,'enable','on', 'Callback',{@uiget_cordeg,cb3,cb1,cb2})
    
else % from previous splitting analysis
    
    [sel_data.set_file, sel_data.results_folder] = ...
        uigetfile('*.txt','please select file with saved settings',...
        [sel_data.work_dir,'/results/']);
    
    fileID = fopen([sel_data.results_folder,sel_data.set_file]);
    C = textscan(fileID,'%f %f %3.1f %f %f %s');
    fclose(fileID);
    
    % write in editable fields
    
    e1 = uicontrol(split_bg1, 'Style', 'edit','String',C{1},'enable', ...
        'off', 'Units', 'normalized', 'position',[0.5,0.5,0.15,0.05],...
        'Callback',@uiget_p1);
    
    e2 = uicontrol(split_bg1, 'Style', 'edit','String',C{2},'enable',...
        'off', 'Units', 'normalized', 'position',[0.75,0.5,0.15,0.05],...
        'Callback',@uiget_p2);
    
    e4 = uicontrol(split_bg1, 'Style', 'edit','String',C{4},'enable', ...
        'off', 'Units', 'normalized', 'position',[0.5,0.4,0.15,0.05],...
        'Callback',@uiget_ntw);
    
    % set radio button - phi range
    if C{5} == 0
        set(split_bg1,'SelectedObject',r2)
    else
        set(split_bg1,'SelectedObject',r1)
    end
    
    % enable radion buttons
    set(r1,'enable','on')
    set(r2,'enable','on')
    set(cb1,'enable','on', 'Callback',{@uiget_cordeg,cb1,cb2,cb3})
    set(cb2,'enable','on', 'Callback',{@uiget_cordeg,cb2,cb3,cb1})
    set(cb3,'enable','on', 'Callback',{@uiget_cordeg,cb3,cb1,cb2})
    
    % call snr back to memory
    sel_data.snr = C{3};
    
    % call set_folder back to memory
    sel_data.set_folder = [sel_data.work_dir,char(C{6})];
    
end

% enable remaining buttons
set(pd1,'enable','on')
set(pb0,'enable','on')
end

function ui_ok(hObject,handles,split_bg1,r1,r2, pb11,pb22,pb33,pb44,pb111,...
    pb222,pb333,pb444,pb555,pb666,cb1,cb2,cb3)

% gets input/settings from fields

global sel_data e1 e2 e4 e5 pd1 C

% check if filter settings agree with pre-processing steps
if length(C) == 3
    
    %get values
    p1 = str2double(get(e1,'String'));
    p2 = str2double(get(e2,'String'));
    
    % check if filter range is within previously used bandpass
    if p1<C{1} || p2>C{2}
        outf = warning_2buttons(...
            ['The specified filter settings are not the same as ',...
            'used in pre-processing. Are you sure you want to continue?'],...
            'yes','no','Warning!');
        if outf == 2
            return
        end
        
    % check if filter is logical
    elseif p2<p1
        w = warndlg(['The specified filter is illogical! ',...
            'Please change to continue. '],...
            'Warning!');
        drawnow
        waitfor(w);
        return
    end
    
end

% get values from fields

uiget_p1(e1)
uiget_p2(e2)
uiget_ntw(e4)
uiget_st(pd1)
uiget_fa_area(split_bg1)

get_tag(1) = get(cb1,'value');
get_tag(2) = get(cb2,'value');
get_tag(3) = get(cb3,'value');

if get_tag(1) == 1
    sel_data.cordeg = 'mean';
elseif get_tag(2) == 1
    sel_data.cordeg = 'single';
else
    sel_data.cordeg = str2double(get(e5,'string'));
end

% create new results folder if it does not exist
% and write saved settings file

set_folder = sel_data.set_folder;
find_fol = strfind(set_folder,'processed');
sub_folder = set_folder(find_fol-1:end);

p1 = get(e1,'String');
p2 = get(e2,'String');
cut_snr = sel_data.snr;
no_tw = get(e4,'String');

save_name = ['Filter_',p1,'-',p2,'s_SNR_',num2str(cut_snr), '_tw_',no_tw];

new_dir = [sel_data.work_dir,'/results/',save_name,'/'];

% check if directory already exists, if not, make new one
if ~exist(new_dir,'dir')
    
    sel_data.results_folder = new_dir;
    mkdir(new_dir)
    
    switch get(get(split_bg1,'SelectedObject'),'Tag')
        case 'Button1'
            fa_area  = 90;
        case 'Button2'
            fa_area  = 0;
    end
    
    fileID = fopen([new_dir,'/saved_settings.txt'], 'w');
    fprintf(fileID, '%s %s %3.1f %s %3.1f %s\n',...
        p1,p2,cut_snr,no_tw,fa_area,sub_folder);
    fclose(fileID);
    
% if chosen setting already exists  
elseif exist(new_dir,'dir') && strcmp(get(e1,'enable'),'on')
    
    w = warndlg(['The specified settings were already used. Please click',...
        ' load settings from "previous splitting analysis" instead'],...
        'Warning!');
    drawnow
    waitfor(w);
    return
    
end

% enable buttons for splitting analysis
set(pb11,'enable', 'on')
set(pb22,'enable', 'on')
set(pb33,'enable', 'on')
set(pb44,'enable', 'on')
set(pb111,'enable', 'on')
set(pb222,'enable', 'on')
set(pb333,'enable', 'on')
set(pb444,'enable', 'on')
set(pb555,'enable', 'on')
set(pb666,'enable', 'on')

% disable other buttons
set(pd1,'enable','off')
set(e1,'enable','off')
set(e2,'enable','off')
set(e4,'enable','off')
set(hObject,'enable','off')
set(cb1,'enable','off')

end
